//
//  ViewController.m
//  WebViewTest
//
//  Created by Si, Steven on 10/23/20.
//

#import "ViewController.h"
#import "ZebraPrinterConnection.h"
#import "ZebraPrinter.h"
#import "ZebraPrinterFactory.h"
#import "TcpPrinterConnection.h"
#import "MfiBtPrinterConnection.h"
#import <ExternalAccessory/ExternalAccessory.h>

@interface ViewController ()

@end

@implementation ViewController
@synthesize customWebView;

- (void)viewDidLoad {
    [super viewDidLoad];

    // Print from JavaScript
    NSString *path = [[NSBundle mainBundle] pathForResource:@"index" ofType:@"html"];
    NSURL *url = [NSURL fileURLWithPath:path];
    NSURLRequest *request = [NSURLRequest requestWithURL:url];

    WKWebViewConfiguration *theConfiguration = [[WKWebViewConfiguration alloc] init];
    [theConfiguration.userContentController addScriptMessageHandler:self name:@"interOp"];

    customWebView = [[WKWebView alloc] initWithFrame:self.view.frame configuration:theConfiguration];
    
    [customWebView loadRequest:request];
    [self.view addSubview:customWebView];
}

- (void)userContentController:(WKUserContentController *)userContentController
      didReceiveScriptMessage:(WKScriptMessage *)message{
    
    NSDictionary *sentData = (NSDictionary*)message.body;
    long aCount = [sentData[@"count"] integerValue];
    aCount++;
    [customWebView evaluateJavaScript:[NSString stringWithFormat:@"incrementCounter(%ld)", aCount] completionHandler:nil];
    
    // Do a label printing
    [NSThread detachNewThreadSelector:@selector(doLabelPrint) toTarget:self withObject:nil];
}

- (void) doLabelPrint {

    id<ZebraPrinterConnection, NSObject> connection = nil;
    
    // Hardcode the SN here
    connection = [[MfiBtPrinterConnection alloc] initWithSerialNumber:@"XXZEJ173500341"]; // ZQ310
//    connection = [[MfiBtPrinterConnection alloc] initWithSerialNumber:@"XXZJJ174600934"]; // ZQ610
    
    BOOL didOpen = [connection open];
    if(didOpen == YES) {
        NSError *error = nil;
        id<ZebraPrinter,NSObject> printer = [ZebraPrinterFactory getInstance:connection error:&error];
        
        if(printer != nil) {
            PrinterLanguage language = [printer getPrinterControlLanguage];
            BOOL sentOK = [self printTestLabel:language onConnection:connection withError:&error];

            if (sentOK == YES) {
//                [self.connectivityViewController setStatus:@"Test Label Sent" withColor:[UIColor greenColor]];
            } else {
//                [self.connectivityViewController setStatus:@"Test Label Failed to Print" withColor:[UIColor redColor]];
            }
        } else {
//            [self.connectivityViewController setStatus:@"Could not Detect Language" withColor:[UIColor redColor]];
        }
    } else {
//        [self.connectivityViewController setStatus:@"Could not connect to printer" withColor:[UIColor redColor]];
    }
    
    [connection close];
}

-(BOOL)printTestLabel:(PrinterLanguage) language onConnection:(id<ZebraPrinterConnection, NSObject>)connection withError:(NSError**)error {
    NSString *testLabel;
    if (language == PRINTER_LANGUAGE_ZPL) {
        testLabel = @"^XA^FO17,16^GB379,371,8^FS^FT65,255^A0N,135,134^FDTEST^FS^XZ";
        NSData *data = [NSData dataWithBytes:[testLabel UTF8String] length:[testLabel length]];
        [connection write:data error:error];
    } else if (language == PRINTER_LANGUAGE_CPCL) {
        testLabel = @"! 0 200 200 406 1\r\nON-FEED IGNORE\r\nBOX 20 20 380 380 8\r\nT 0 6 137 177 TEST\r\nPRINT\r\n";
        NSData *data = [NSData dataWithBytes:[testLabel UTF8String] length:[testLabel length]];
        [connection write:data error:error];
    }
    if(*error == nil){
        return YES;
    } else {
        return NO;
    }
}

@end
